@@ -2,7 +2,7 @@
 * fileoutput.cpp: file output
 *-------------------------------------------------------------------------------
 * (c)1999-2001 VideoLAN
-* $Id: fileoutput.cpp,v 1.2 2002/08/09 13:42:32 tooney Exp $
+* $Id: fileoutput.cpp,v 1.4 2002/12/03 23:32:17 nitrox Exp $
 *
 * Authors: James Courtier-Dutton <James@superbug.demon.co.uk>
 *          Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
@@ -72,13 +72,20 @@ C_FileOutput::~C_FileOutput()
 //------------------------------------------------------------------------------
 void C_FileOutput::OnInit()
 {
-  {
     // Open the file
     if(m_bAppend)
-      m_cFile.Open("a+");
-    else
+#ifdef WIN32
+  	m_cFile.Open("ab+");
+#else
+  	m_cFile.Open("a+");
+#endif
+    	else
+#ifdef WIN32
+      m_cFile.Open("wb+");
+#else
       m_cFile.Open("w+");
-  }
+#endif
+  
 }
 
 
